"""Provide version and author details."""


__title__ = "steelconnection"
__description__ = "Simplify access to the Riverbed SteelConnect REST API."
__version__ = "1.0.0"
__author__ = "Greg Mueller"
__author_email__ = "steelconnection@grelleum.com"
__copyright__ = "Copyright 2018 Greg Mueller"
__license__ = "MIT"
__url__ = "https://github.com/grelleum/SteelConnection"
__documentation__ = "https://steelconnection.readthedocs.io/"



# coding: utf-8

"""SteelConnection

Convienience object for ID value lookups based on common criteria.

Should be instantiated within a steelconnection object.
"""


class _LookUp(object):
    """Provide convienience tools to lookup objects."""

    def __init__(self, sconnect):
        """Obtain access to SteelConect Manager."""
        self.sconnect = sconnect
        self._models = model

    def _lookup(self, domain, value, key):
        """
        Generic lookup function.
        Given a resource type (domain), a value to match, and a key to lookup,
        returns a dictionary representing the object.
        """
        items = self.sconnect.get(domain)
        for item in items:
            if value == item.get(key):
                self.sconnect.result = item
                return item
        return None

    def node(self, serial, key="serial"):
        """
        Returns a node matching a provided appliance serial number.
        """
        return self._lookup(domain="nodes", value=serial, key=key)

    def org(self, name, key="name"):
        """
        Returns a org matching a provided organization short name.
        """
        return self._lookup(domain="orgs", value=name, key=key)

    def site(self, name, orgid=None, key="name"):
        """
        Returns a site matching a provided site short name and org_id.
        """
        if not orgid:
            raise ValueError("orgid required when looking up a site.")
        resource = "/".join(("org", orgid, "sites"))
        return self._lookup(domain=resource, value=name, key=key)

    def wan(self, name, orgid=None, key="name"):
        """
        Returns a wan matching a provided wan name and org_id.
        """
        if not orgid:
            raise ValueError("orgid required when looking up a wan.")
        resource = "/".join(("org", orgid, "wans"))
        return self._lookup(domain=resource, value=name, key=key)

    def model(self, value, default=None):
        """
        Translates a model code name to real name and visa versa.
        """
        default = default if default else value
        return self._models.get(value, default)


model = {
    "aardvark": "SDI-S12",
    "baloo": "SDI-SH",
    "beorn": "SDI-ZAKSH",
    "booboo": "SDI-AWS",
    "cx3070": "3070-SD",
    "cx570": "570-SD",
    "cx770": "770-SD",
    "ewok": "SDI-330",
    "fozzy": "SDI-USB",
    "grizzly": "SDI-1030",
    "koala": "SDI-AP5",
    "kodiak": "SDI-S48",
    "misha": "SDI-AZURE-SH",
    "paddington": "SDI-AZURE",
    "panda": "SDI-130",
    "panther": "SDI-5030",
    "raccoon": "SDI-AP3",
    "sloth": "SDI-S24",
    "tiger1g": "SDI-2030",
    "ursus": "SDI-AP5r",
    "xirrusap": "Xirrus AP",
    "yogi": "SDI-VGW",
}

model_reversed = sorted((v, k) for k, v in model.items())
model.update(dict(model_reversed))



from setuptools import setup
import re

name = "steelconnection"
description = "Simplify access to the Riverbed SteelConnect REST API."
version = "1.0.0"
copyright = "Copyright 2018 Greg Mueller"

info = {
    "description": description,
    "version": version,
    "author": "Greg Mueller",
    "author_email": "steelconnection@grelleum.com",
    "license": "MIT",
    "project_urls": {
        "Documentation": "https://steelconnection.readthedocs.io/",
        "Source": "https://github.com/grelleum/SteelConnection",
    },
    "long_description_content_type": "text/x-rst",
    "install_requires": ["requests>=2.12.1"],
    "keywords": ["SteelConnect", "REST", "API", "Riverbed", "Grelleum"],
    "packages": ["steelconnection"],
    "classifiers": [
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
}


def create_version_file(info):
    export_info = {k: v for k, v in info.items()}
    export_info["title"] = name
    export_info["copyright"] = copyright
    keys = [
        "title",
        "description",
        "version",
        "author",
        "author_email",
        "copyright",
        "license",
    ]
    text = '__{}__ = "{}"\n'
    with open(name + "/__version__.py", "wt") as f:
        f.write('"""Provide version and author details."""\n\n\n')
        for key in keys:
            f.write(text.format(key, export_info[key]))
        f.write(text.format("url", info["project_urls"]["Source"]))
        f.write(text.format("documentation", info["project_urls"]["Documentation"]))


def read_and_update_readme(filename):
    with open(filename, "rt") as f:
        readme = f.read()
    long_description = re.sub(
        r"   version \d+\.[\d\.]+[a-z]?", "   version " + info["version"], readme
    )
    with open(filename, "wt") as f:
        f.write(long_description)
    return long_description


print("VERSION:", info["version"])
create_version_file(info)
# if '.tox' not in '-'.join(sys.argv):
#     _ = read_and_update_readme('docs/index.rst')
long_description = read_and_update_readme("README.rst")
info["long_description"] = long_description
setup(name=name, **info)
